# LibreOffice AppImage Helper - `loaih` #

LibreOffice AppImage Helper is an enhanced Python porting from [previous work
from Antonio
Faccioli](https://github.com/antoniofaccioli/libreoffice-appimage). It helps
building a LibreOffice AppImage from officially released .deb files with some
options.

## Getting options and help ##

You can ask the app some information on how you can use it:

    $ loaih --help
    $ loaih getversion --help
    $ loaih build --help
    $ loaih batch --help

For any other information needed, please visit the [wiki of the
project](https://git.libreitalia.org/libreitalia/loaih/wiki).
